==> hubzero-cms-2.0.0_2.0.0.0.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.0/cms/core/plugins/hubzero/sysusers/sysusers.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2014 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2014 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// No direct access
defined('_HZEXEC_') or die();

/**
 * HUBzero plugin class for system overview
 */
class plgHubzeroSysusers extends \Hubzero\Plugin\Plugin
{
	/**
	 * Return information about this hub
	 *
	 * @return  array
	 */
	public function onSystemOverview($values = 'all')
	{
		$database = App::get('db');

		$response = new stdClass;
		$response->name  = 'users';
		$response->label = 'Users';
		$response->data  = array();

		if ($values == 'all')
		{
			$database->setQuery("SELECT COUNT(*) FROM `#__users`");
			$response->data['total'] = $this->_obj('Total', $database->loadResult());

			$database->setQuery("SELECT COUNT(*) FROM `#__xprofiles` WHERE `emailConfirmed` < 1");
			$response->data['unconfirmed'] = $this->_obj('Unconfirmed', $database->loadResult());

			$response->data['confirmed'] = $this->_obj('Confirmed', ($response->data['total']->value - $response->data['unconfirmed']->value));

			$database->setQuery("SELECT `lastvisitDate` FROM `#__users` ORDER BY `lastvisitDate` DESC LIMIT 1");
			$response->data['last_visit'] = $this->_obj('Last user login', $database->loadResult());
		}

		if ($values == 'all' || $values == 'short')
		{
			$database->setQuery("SELECT COUNT(*) FROM `#__session` WHERE `guest`=0 AND `time` >= UNIX_TIMESTAMP(NOW() - INTERVAL 15 MINUTE) AND `client_id`=0;");
			$response->data['site'] = $this->_obj('Active (site)', $database->loadResult());

			$database->setQuery("SELECT COUNT(*) FROM `#__session` WHERE `guest`=0 AND `time` >= UNIX_TIMESTAMP(NOW() - INTERVAL 15 MINUTE) AND `client_id`=1;");
			$response->data['admin'] = $this->_obj('Active (admin)', $database->loadResult());
		}

		return $response;
	}

	/**
	 * Assign label and data to an object
	 *
	 * @param   string $label
	 * @param   mixed  $value
	 * @return  object
	 */
	private function _obj($label, $value)
	{
		$obj = new stdClass;
		$obj->label = $label;
		$obj->value = $value;

		return $obj;
	}
}

==> hubzero-cms-2.1.0_2.1.0.15.orig.tar.gz: hubzero-cms-2.1.0-2.1.0.15/cms/core/plugins/hubzero/sysusers/sysusers.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access
defined('_HZEXEC_') or die();

/**
 * HUBzero plugin class for system overview
 */
class plgHubzeroSysusers extends \Hubzero\Plugin\Plugin
{
	/**
	 * Return information about this hub
	 *
	 * @return  array
	 */
	public function onSystemOverview($values = 'all')
	{
		$database = App::get('db');

		$response = new stdClass;
		$response->name  = 'users';
		$response->label = 'Users';
		$response->data  = array();

		if ($values == 'all')
		{
			$database->setQuery("SELECT COUNT(*) FROM `#__users`");
			$response->data['total'] = $this->_obj('Total', $database->loadResult());

			$database->setQuery("SELECT COUNT(*) FROM `#__xprofiles` WHERE `emailConfirmed` < 1");
			$response->data['unconfirmed'] = $this->_obj('Unconfirmed', $database->loadResult());

			$response->data['confirmed'] = $this->_obj('Confirmed', ($response->data['total']->value - $response->data['unconfirmed']->value));

			$database->setQuery("SELECT `lastvisitDate` FROM `#__users` ORDER BY `lastvisitDate` DESC LIMIT 1");
			$response->data['last_visit'] = $this->_obj('Last user login', $database->loadResult());
		}

		if ($values == 'all' || $values == 'short')
		{
			$database->setQuery("SELECT COUNT(*) FROM `#__session` WHERE `guest`=0 AND `time` >= UNIX_TIMESTAMP(NOW() - INTERVAL 15 MINUTE) AND `client_id`=0;");
			$response->data['site'] = $this->_obj('Active (site)', $database->loadResult());

			$database->setQuery("SELECT COUNT(*) FROM `#__session` WHERE `guest`=0 AND `time` >= UNIX_TIMESTAMP(NOW() - INTERVAL 15 MINUTE) AND `client_id`=1;");
			$response->data['admin'] = $this->_obj('Active (admin)', $database->loadResult());
		}

		return $response;
	}

	/**
	 * Assign label and data to an object
	 *
	 * @param   string $label
	 * @param   mixed  $value
	 * @return  object
	 */
	private function _obj($label, $value)
	{
		$obj = new stdClass;
		$obj->label = $label;
		$obj->value = $value;

		return $obj;
	}
}
